@@ -275,7 +275,8 @@ class ipdb(dotkeys):
     No methods of the class should be called directly.
     '''
 
-    def __init__(self, ipr=None):
+    def __init__(self, ipr=None, host='localsystem',
+                 key=None, cert=None, ca=None):
         '''
         Parameters:
             * ipr -- iproute() reference
@@ -286,7 +287,7 @@ class ipdb(dotkeys):
         you can start two and more iproute instances, but
         only the first one will receive anything.
         '''
-        self.ip = ipr or iproute()
+        self.ip = ipr or iproute(host=host, key=key, cert=cert, ca=ca)
 
         # caches
         self.ipaddr = {}
@@ -335,7 +336,10 @@ class ipdb(dotkeys):
         database.
         '''
         while True:
-            messages = self.ip.get()
+            try:
+                messages = self.ip.get()
+            except:
+                continue
             for msg in messages:
                 if msg.get('event', None) == 'RTM_NEWLINK':
                     index = msg['index']
